# Interest Calculator 

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)                 
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)   

## Functionality of the Music Player

- Interest Calculator
- Addition
- Subtraction
- Division
- Multiplication
- Modulo
- Square function


## Usage

- Make sure you have Python installed in your system.
- Run Following command in the CMD.
 ```
  pip install simple_calculator
  ```
## Example(Calculate Loan Interest)

 ```
## test.py 

from interest_calculator import interest

## calling simply interest()  function they are automatic work
 
 syntax:
            from interest_calculator import interest   
            interest()
   
Output:
> interest()               #user input function use
Principal Amount : 100
Interest Rate : 10
Enter Months : 10
Enter Years : 0
Interest Earned :  8.33
Total Amount(Principal + Interest) :  108.33

 ```
  Function
 ```
interest()
add()
sub()
mul()
mod()
mul()
square()

This function are avalible our package.
I hope enjoy our package
Thank You